@@ -1,5 +1,5 @@
 package Finance::Dogechain::Block;
-$Finance::Dogechain::Block::VERSION = '1.20210524.0142';
+$Finance::Dogechain::Block::VERSION = '1.20210605.1754';
 use Mojo::Base -base, -signatures, 'Finance::Dogechain::Base';
 use Finance::Dogechain::Transaction;
 
@@ -19,7 +19,9 @@ sub convert_transactions_in_place($txs) {
 }
 
 sub transactions($self) {
-    return $self->block->{txs};
+    # a coinbase block may not come back as a block with a height
+    # so return no transactions
+    return $self->block ? $self->block->{txs} : [];
 }
 
 sub TO_JSON($self) {
@@ -80,8 +82,16 @@ when possible.
 Returns an undefined value (C<undef> in scalar context or an empty list in list
 context) if the HTTP call did not succeed.
 
+This may also return an undefined value for coinbase blocks.
+
 Returns C<0> if the HTTP call did succeed but the API returned an unsuccessful payload.
 
+=head2 transactions()
+
+Returns an array reference of all transactions in this block. This array
+reference may be empty if there are no transactions, as in the case when the
+block is a coinbase, for example.
+
 =head2 TO_JSON()
 
 Returns a string representation of this object (its class and C<block_id>) so that
